#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui/QMainWindow>
#include "settings.h"
#include "importflashcard.h"

namespace Ui
{
    class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow(QWidget *parent = 0);
    ~MainWindow();
    void handleSelection(int);
//    void showAbout();

private:
    Ui::MainWindow *ui;
    Settings *dlgSettings;
    importflashcard *dlgShowFlashcards;
/*
    Phonon::MediaObject *mediaObject;
    Phonon::AudioOutput *audioOutput;
    Phonon::Path mediaPath;
*/
//	QtCore::QtPropertyAnimation animation;


public slots:
    void setSide3(const QString &text);
    void setSide1(const QString &text);
    void setMandarin(const QString &text);
    void setSide2(const QString &text);
    void SettingsMenu();
    void showAbout();
    void showImportFlashcards();
    void purgeAll();

private slots:
    void on_pbBad_clicked();
    void on_pbOK_clicked();
    void on_pbGood_clicked();
//    void on_pbSettings_clicked();
//    void on_pushButton_6_clicked();
    void on_pbShow_clicked();

signals:
    void side3Changed(const QString&);
    void side1Changed(const QString&);
    void side2Changed(const QString&);
    void mandarinChanged(const QString&);

};

#endif // MAINWINDOW_H
